"""
The main API module for making requests.
"""

import requests
from requests.exceptions import HTTPError


class BlockPulsarAPI:
    """
    Blockpulsar API class which provides a get method for making a GET request.
    """
    def __init__(self, api_key: str, secret_key: str):
        self.header = {
            'User-Agent': 'blockpulsar-client-python 1.0.0',
            'x-api-key': api_key,
            'x-api-secret': secret_key
        }

    def get(self, route: str, params=None):
        try:
            url = f'https://api.blockpulsar.com/{route}'
            response = requests.get(url, headers=self.header, params=params)
            return response.json()
        except HTTPError as http_err:
            print(f'HTTP error occurred: {http_err}')
        except Exception as err:
            print(f'Error occurred: {err}')
        return None
